# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.1]

This release fixes bugs caused by PyFLP's breaking changes.

### Added

- Testing with `tox`.
- Linting with `flake8` and `bandit`.
- **TODO** section in `README.md`.

### Changed

- CI.
- Method and variable names to better reflect their internal nature.

### Removed

- `flpinfo.py`; merged in `__main__.py`.
- `TODO.md`

## [0.1.0]

Initial release

[0.1.1]: https://github.com/demberto/PyFLP/compare/0.1.0...0.1.1
[0.1.0]: https://github.com/demberto/PyFLP/releases/tag/0.1.0
